==> sdlskk-0.3.tar.gz: sdlskk-0.3/testrender.c <==
#include <sdlskk.h>
#include <SDL.h>
#include <SDL_ttf.h>

SDL_Surface* screen;
SDLSKK_Context* context;
SDLSKK_RomKanaRuleTable* table;
SDLSKK_Dictionary* dict;
TTF_Font* font;
int use_minibuffer=0;
Uint32 white_pixelvalue;

SDL_Color white = { 0xFF, 0xFF, 0xFF, 0 };

void SDLSKK_Quit()
{
  SDLSKK_Context_delete( context );
  SDLSKK_RomKanaRuleTable_delete( table );
  SDLSKK_Dict_delete_all( dict );
}

void init( int argc, char** argv )
{
  if( argc > 1 )
    use_minibuffer = ( strcmp( argv[1], "-m" ) == 0 );
  
  SDLSKK_set_encoding( SDLSKK_EUCJP );
  
  dict = SDLSKK_Dict_new();
  SDLSKK_Dict_load( dict, "test_jisyo", 0 );
  
  table = SDLSKK_RomKanaRuleTable_new( "test_rule_table" );
  context = SDLSKK_Context_new( dict, table, use_minibuffer );

  atexit( SDLSKK_Quit );
  
  if( SDL_Init( SDL_INIT_VIDEO ) < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( SDL_Quit );
  if( TTF_Init() < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( TTF_Quit );

  font = TTF_OpenFont( "sample.ttf", 14 );
  if( font == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  
  screen = SDL_SetVideoMode( 640, 480, 16, SDL_SWSURFACE );
  if( screen == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }

  white_pixelvalue = SDL_MapRGB( screen->format, 255, 255, 255 );
  
  SDL_EnableUNICODE( 1 );
  SDL_EnableKeyRepeat( SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL );
  return;
}


int main( int argc, char** argv )
{ 
  char buf[4098];
  SDL_Surface* tmp_surface;
  SDL_Surface* minibuffer_surface;
  SDL_Rect rect = { 0, 0, 640, 480 };
  SDL_Rect minibuffer_rect = { 0, 465, 0, 0 };
  SDL_Rect minibuffer_frame_rect = { 0, 462, 640, 2 };
  
  init( argc, argv );
  
  for(;;){
    SDL_Event event;
    while( SDL_PollEvent(&event) ){
      switch(event.type){
      case SDL_KEYDOWN:
	if( event.key.keysym.sym == SDLK_ESCAPE )
	  return 0;
	SDLSKK_Context_input_event( context, &event );
	if( event.key.keysym.sym == SDLK_TAB ){
	  SDLSKK_Context_get_display_str( context, buf, sizeof( buf ) );
	  printf( "%s\n", buf );
	}	
	break;
      case SDL_QUIT:
	return 0;
      }
      
      tmp_surface = SDLSKK_Context_render_display_str( context, font, white );
      SDL_FillRect( screen, &rect, 0 );
      SDL_BlitSurface( tmp_surface, NULL, screen, NULL );
      
      if( use_minibuffer ){
	SDL_FillRect( screen, &minibuffer_frame_rect, white_pixelvalue );
	
	minibuffer_surface = 
	  SDLSKK_Context_render_minibuffer_str( context, font, white );
	if( minibuffer_surface )
	  SDL_BlitSurface( minibuffer_surface, NULL, screen, &minibuffer_rect);
      }
      
      SDL_Flip( screen );
      SDL_FreeSurface( tmp_surface );
      SDL_Delay( 50 );      
    }
  }
}

==> sdlskk-0.4.tar.gz: sdlskk-0.4/testrender.c <==
#include <sdlskk.h>
#include <SDL.h>
#include <SDL_ttf.h>

SDL_Surface* screen;
SDLSKK_Context* context;
SDLSKK_RomKanaRuleTable* table;
SDLSKK_Dictionary* dict;
SDLSKK_Keybind* keybind;
TTF_Font* font;
int use_minibuffer=0;
Uint32 white_pixelvalue;

SDL_Color white = { 0xFF, 0xFF, 0xFF, 0 };

void SDLSKK_Quit()
{
  SDLSKK_Context_delete( context );
  SDLSKK_RomKanaRuleTable_delete( table );
  SDLSKK_Dict_delete_all( dict );
  SDLSKK_Keybind_delete( keybind );
}

void init( int argc, char** argv )
{
  if( argc > 1 )
    use_minibuffer = ( strcmp( argv[1], "-m" ) == 0 );
  
  SDLSKK_set_encoding( SDLSKK_EUCJP );
  
  dict = SDLSKK_Dict_new();
  SDLSKK_Dict_load( dict, "test_jisyo", 0 );
  
  table = SDLSKK_RomKanaRuleTable_new( "test_rule_table" );
  
  keybind = SDLSKK_Keybind_new();
  SDLSKK_Keybind_set_default_key( keybind );
    
  context = SDLSKK_Context_new( dict, table, keybind, use_minibuffer );

  atexit( SDLSKK_Quit );
  
  if( SDL_Init( SDL_INIT_VIDEO ) < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( SDL_Quit );
  if( TTF_Init() < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( TTF_Quit );

  font = TTF_OpenFont( "sample.ttf", 14 );
  if( font == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  
  screen = SDL_SetVideoMode( 640, 480, 16, SDL_SWSURFACE );
  if( screen == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  
  SDL_WM_SetCaption( "sdlskk library test", "sdlskk lib test" );

  white_pixelvalue = SDL_MapRGB( screen->format, 255, 255, 255 );
  
  SDL_EnableUNICODE( 1 );
  SDL_EnableKeyRepeat( SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL );
  return;
}


int main( int argc, char** argv )
{ 
  char buf[4098];
  SDL_Surface* tmp_surface;
  SDL_Surface* minibuffer_surface;
  SDL_Rect rect = { 0, 0, 640, 480 };
  SDL_Rect minibuffer_rect = { 0, 465, 0, 0 };
  SDL_Rect minibuffer_frame_rect = { 0, 462, 640, 2 };
  
  init( argc, argv );
  
  for(;;){
    SDL_Event event;
    while( SDL_PollEvent(&event) ){
      switch(event.type){
      case SDL_KEYDOWN:
	if( event.key.keysym.sym == SDLK_ESCAPE )
	  return 0;
	SDLSKK_Context_input_event( context, &event );
	if( event.key.keysym.sym == SDLK_TAB ){
	  SDLSKK_Context_get_display_str( context, buf, sizeof( buf ) );
	  printf( "%s\n", buf );
	}	
	break;
      case SDL_QUIT:
	return 0;
      }
      
      tmp_surface = SDLSKK_Context_render_display_str( context, font, white );
      SDL_FillRect( screen, &rect, 0 );
      SDL_BlitSurface( tmp_surface, NULL, screen, NULL );
      
      if( use_minibuffer ){
	SDL_FillRect( screen, &minibuffer_frame_rect, white_pixelvalue );
	
	minibuffer_surface = 
	  SDLSKK_Context_render_minibuffer_str( context, font, white );
	if( minibuffer_surface )
	  SDL_BlitSurface( minibuffer_surface, NULL, screen, &minibuffer_rect);
      }
      
      SDL_Flip( screen );
      SDL_FreeSurface( tmp_surface );
      SDL_Delay( 50 );      
    }
  }
}
